!
! $Header: /home/ssipsl/CVSREP/ORCHIDEE/src_stomate/stomate_constants.f90,v 1.8 2002/11/07 17:50:49 ssipsl Exp $
!
MODULE stomate_constants

  USE reqdprec
  USE constantes_veg

  ! Number of pfts
  INTEGER(long), PARAMETER                             :: npft = nvm-1

  INTEGER(long), PARAMETER                             :: ibare_sechiba = 1

  ! which Sechiba-PFT corresponds to a given Stomate-PFT
  INTEGER(long), SAVE, DIMENSION(npft)           :: ipft_sechiba

  ! how many Stomate-PFTs correspond to each Sechiba-PFT? e.g. for age classes
  INTEGER(long), SAVE, DIMENSION(nvm)            :: npft_stomate

  ! 0 = no, 4 = full online diagnostics
  INTEGER(short), SAVE                           :: bavard=1
  ! write forcing file for carbon spinup?
  LOGICAL, SAVE                                  :: write_carbonforce
  ! Horizontal indices
  INTEGER(long), ALLOCATABLE, SAVE, DIMENSION(:)       :: hori_index
  ! Horizonatal + PFT indices
  INTEGER(long), ALLOCATABLE, SAVE, DIMENSION(:)       :: horipft_index
  ! time step
  INTEGER(long), SAVE                                  :: itime
  ! STOMATE history file ID
  INTEGER(long), SAVE                                  :: hist_id_stomate
  ! STOMATE restart file ID
  INTEGER(long), SAVE                                  :: rest_id_stomate

  ! Freezing point
  REAL(stnd), PARAMETER                          :: ZeroCelsius = 273.15
  ! e
  REAL(stnd), PARAMETER                          :: euler = 2.71828182846
  ! Epsilon to detect a near zero floating point
  REAL(stnd), PARAMETER                          :: min_stomate = 1.E-8_stnd
  ! some large value
  REAL(stnd), PARAMETER                          :: large_value = 1.E33_stnd
  ! Special value
  REAL(stnd), PARAMETER                          :: undef = -9999.
  ! Length of a day (in seconds)
  REAL(stnd), PARAMETER                          :: one_day = 86400.
  ! Length of a year (in days)
  REAL(stnd), PARAMETER                          :: one_year = 365.2425

  ! maximum reference long term temperature (K)
  REAL(stnd), PARAMETER                          :: tlong_ref_max=303.1
  ! minimum reference long term temperature (K)
  REAL(stnd), PARAMETER                          :: tlong_ref_min=253.1

  ! trees and litter: indices for the parts of heart- and sapwood above
  !   and below the ground
  INTEGER(long), PARAMETER                       :: iabove = 1
  INTEGER(long), PARAMETER                       :: ibelow = 2
  INTEGER(long), PARAMETER                       :: nlevs = 2

  ! litter: indices for metabolic and structural part
  INTEGER(long), PARAMETER                       :: imetabolic = 1
  INTEGER(long), PARAMETER                       :: istructural = 2
  INTEGER(long), PARAMETER                       :: nlitt = 2

  ! carbon pools: indices
  INTEGER(long), PARAMETER                       :: iactive = 1
  INTEGER(long), PARAMETER                       :: islow = 2
  INTEGER(long), PARAMETER                       :: ipassive = 3
  INTEGER(long), PARAMETER                       :: ncarb = 3

  ! litter fractions: indices
  INTEGER(long), PARAMETER                       :: ileaf = 1
  INTEGER(long), PARAMETER                       :: isapabove = 2
  INTEGER(long), PARAMETER                       :: isapbelow = 3
  INTEGER(long), PARAMETER                       :: iheartabove = 4
  INTEGER(long), PARAMETER                       :: iheartbelow = 5
  INTEGER(long), PARAMETER                       :: iroot = 6
  INTEGER(long), PARAMETER                       :: ifruit = 7
  INTEGER(long), PARAMETER                       :: icarbres = 8
  INTEGER(long), PARAMETER                       :: nparts = 8

  ! vegetation types: natural and agricultural
  INTEGER(long), PARAMETER                       :: inat = 1
  INTEGER(long), PARAMETER                       :: iagri = 2
  INTEGER(long), PARAMETER                       :: nvegtypes = 2

  ! transformation between types of surface
  INTEGER(long), PARAMETER                       :: ito_natagri = 1
  INTEGER(long), PARAMETER                       :: ito_total = 2

  ! leaf age discretisation ( 1 = no discretisation )
  INTEGER(long), PARAMETER                       :: nleafages = 4

  ! alpha's : ?
  REAL(stnd), PARAMETER                          :: alpha_grass = .5
  REAL(stnd), PARAMETER                          :: alpha_tree = 1.

  ! type declaration for photosynthesis
  TYPE t_photo_type
    REAL(stnd), DIMENSION(npft)                  :: t_max_a
    REAL(stnd), DIMENSION(npft)                  :: t_max_b
    REAL(stnd), DIMENSION(npft)                  :: t_max_c
    REAL(stnd), DIMENSION(npft)                  :: t_opt_a
    REAL(stnd), DIMENSION(npft)                  :: t_opt_b
    REAL(stnd), DIMENSION(npft)                  :: t_opt_c
    REAL(stnd), DIMENSION(npft)                  :: t_min_a
    REAL(stnd), DIMENSION(npft)                  :: t_min_b
    REAL(stnd), DIMENSION(npft)                  :: t_min_c
  END TYPE t_photo_type

  ! type declaration for phenology
  TYPE pheno_type
    REAL(stnd), DIMENSION(npft,3)                :: gdd
    REAL(stnd), DIMENSION(npft)                  :: ngd
    REAL(stnd), DIMENSION(npft)                  :: ncdgdd_temp
    REAL(stnd), DIMENSION(npft)                  :: hum_frac
    REAL(stnd), DIMENSION(npft)                  :: lowgpp_time
    REAL(stnd), DIMENSION(npft)                  :: leaffall
    REAL(stnd), DIMENSION(npft)                  :: leafagecrit
    REAL(stnd)                                   :: tau_hum_month
    REAL(stnd)                                   :: tau_hum_week
    REAL(stnd)                                   :: tau_t2m_month
    REAL(stnd)                                   :: tau_t2m_week
    REAL(stnd)                                   :: tau_tsoil_month
    REAL(stnd)                                   :: tau_soilhum_month
    REAL(stnd)                                   :: tau_gpp_week
    REAL(stnd)                                   :: tau_gdd
    REAL(stnd)                                   :: tau_ngd
    REAL(stnd)                                   :: tau_longterm
    REAL(stnd), DIMENSION(npft)                  :: lai_initmin
    CHARACTER(len=6), DIMENSION(npft)            :: pheno_model
    CHARACTER(len=6), DIMENSION(npft)            :: senescence_type
    REAL(stnd), DIMENSION(npft,3)                :: senescence_temp
    REAL(stnd), DIMENSION(npft)                  :: senescence_hum
    REAL(stnd), DIMENSION(npft)                  :: nosenescence_hum
    REAL(stnd), DIMENSION(npft)                  :: max_turnover_time
    REAL(stnd), DIMENSION(npft)                  :: min_turnover_time

    REAL(stnd), DIMENSION(npft)                  :: hum_min_time
  END TYPE pheno_type

  ! parameters for the pipe model

  ! crown area = pipe_tune1. stem diameter**(1.6) (Reinicke's theory)
  REAL(stnd), PARAMETER                          :: pipe_tune1 = 100.0
  ! height=pipe_tune2 * diameter**pipe_tune3
  REAL(stnd), PARAMETER                          :: pipe_tune2 = 40.0
  REAL(stnd), PARAMETER                          :: pipe_tune3 = 0.5
  ! needed for stem diameter
  REAL(stnd), PARAMETER                          :: pipe_tune4 = 0.3
  ! Density
  REAL(stnd), PARAMETER                          :: pipe_density = 2.e5
  ! one more parameter
  REAL(stnd), PARAMETER                          :: pipe_k1 = 8.e3

  ! Maximum tree establishment rate
  REAL(stnd), PARAMETER                          :: estab_max_tree = 0.12
  ! Maximum grass establishment rate
  REAL(stnd), PARAMETER                          :: estab_max_grass = 0.12
  ! initial density of individuals
  REAL(stnd), PARAMETER                          :: ind_0 = 0.02

  ! allow agricultural PFTs?
  LOGICAL, SAVE                                  :: agriculture 

  ! Do we treat PFT expansion across a grid point after introduction?
  ! default = .FALSE.
  LOGICAL, SAVE                                  :: treat_expansion = .FALSE.

  ! herbivores?
  LOGICAL, SAVE                                  :: ok_herbivores = .FALSE.

  ! For trees, minimum fraction of crown area occupied (due to its branches etc.)
  ! This means that only a small fraction of its crown area can be invaded by other
  ! trees.
  REAL(stnd), PARAMETER                          :: min_cover = 0.05

  ! climatic parameters

  ! minimum precip, in mm/year
  REAL(stnd), PARAMETER                          :: precip_crit = 100.
  ! minimum gdd for establishment of saplings
  REAL(stnd), PARAMETER                          :: gdd_crit = 150.
  ! critical fpc, needed for light competition and establishment
  REAL(stnd), PARAMETER                          :: fpc_crit = 0.95

  ! critical value for being adapted (1-1/e)
  REAL(stnd), PARAMETER                          :: adapted_crit = 1. - ( 1. / euler )
  ! critical value for being regenerative (1/e)
  REAL(stnd), PARAMETER                          :: regenerate_crit = 1. / euler

  ! fraction of GPP which is lost as growth respiration
  REAL(stnd), PARAMETER                          :: frac_growthresp = 0.28

  ! radius of the Earth (m)
  REAL(stnd), PARAMETER                          :: R_Earth = 6378000.

  ! description of the PFT
  CHARACTER(len=34), SAVE, DIMENSION(npft)              :: PFT_name
  ! extinction coefficient of the Monsi&Seaki (53) relationship
  REAL(stnd), SAVE, DIMENSION(npft)                     :: ext_coeff
  ! is pft a tree
  LOGICAL, SAVE, DIMENSION(npft)                        :: tree
  ! leaf type
  INTEGER(long), SAVE, DIMENSION(npft)                  :: leaf_tab
  ! natural? 
  LOGICAL, SAVE, DIMENSION(npft)                        :: natural
  ! flamability: critical fraction of water holding capacity
  REAL(stnd), SAVE, DIMENSION(npft)                     :: flam
  ! fire resistance
  REAL(stnd), SAVE, DIMENSION(npft)                     :: resist
  ! specific leaf area (m**2/gC)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: sla
  ! sapling biomass (gC/ind)
  REAL(stnd), SAVE, DIMENSION(npft,nparts)              :: bm_sapl
  ! migration speed (m/year)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: migrate
  ! maximum stem diameter from which on crown area no longer increases (m)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: maxdia
  ! critical minimum temperature (K)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tmin_crit
  ! critical temperature of the coldest month (K)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tcm_crit
  ! critical values for phenology
  TYPE(pheno_type), SAVE                                :: pheno_crit
  ! time constant for leaf age discretisation (d)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: leaf_timecst
  ! maximum LAI, PFT-specific
  REAL(stnd), SAVE, DIMENSION (npft)                    :: lai_max
  ! maintenance respiration coefficient (g/g/day) at 0 deg C
  REAL(stnd), SAVE, DIMENSION(npft,nparts)              :: coeff_maint_zero
  ! slope of maintenance respiration coefficient (1/K, 1/K^2, 1/K^3)
  REAL(stnd), SAVE, DIMENSION(npft,3)                   :: maint_resp_slope
  ! residence time (y) of trees
  REAL(stnd), SAVE, DIMENSION(npft)                     :: residence_time
  ! leaf lifetime, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: leaflife_tab
  ! type of phenology
  INTEGER(long), SAVE, DIMENSION(npft)                  :: pheno_type_tab
  ! critical tmin, tabulated (C)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tmin_crit_tab
  ! critical tcm, tabulated (C)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tcm_crit_tab
  ! critical gdd, tabulated (C), constant c of aT^2+bT+c
  REAL(stnd), SAVE, DIMENSION(npft)                     :: gdd_crit1_tab
  ! critical gdd, tabulated (C), constant b of aT^2+bT+c
  REAL(stnd), SAVE, DIMENSION(npft)                     :: gdd_crit2_tab
  ! critical gdd, tabulated (C), constant a of aT^2+bT+c
  REAL(stnd), SAVE, DIMENSION(npft)                     :: gdd_crit3_tab
  ! critical ngd, tabulated. Threshold -5 degrees
  REAL(stnd), SAVE, DIMENSION(npft)                     :: ngd_crit_tab
  ! critical temperature for the ncd vs. gdd function in phenology
  REAL(stnd), SAVE, DIMENSION(npft)                     :: ncdgdd_temp_tab
  ! critical humidity (relative to min/max) for phenology
  REAL(stnd), SAVE, DIMENSION(npft)                     :: hum_frac_tab
  ! minimum duration of dormance (d) for phenology
  REAL(stnd), SAVE, DIMENSION(npft)                     :: lowgpp_time_tab
  ! minimum time elapsed since moisture minimum (d)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: hum_min_time_tab
  ! sapwood -> heartwood conversion time (d)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tau_sap
  ! fruit lifetime (d)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tau_fruit
  ! fraction of primary leaf and root allocation put into reserve
  REAL(stnd), SAVE, DIMENSION(npft)                     :: ecureuil
  ! Maximum rate of carboxylation
  REAL(stnd), SAVE, DIMENSION(npft)                     :: vcmax_opt
  ! Maximum rate of RUbp regeneration
  REAL(stnd), SAVE, DIMENSION(npft)                     :: vjmax_opt
  ! constants needed for photosynthesis temperatures
  TYPE(t_photo_type), SAVE                              :: t_photo
  ! lenth of death of leaves, tabulated (d)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: leaffall_tab
  ! critical leaf age, tabulated (d)
  REAL(stnd), SAVE, DIMENSION(npft)                     :: leafagecrit_tab
  ! which phenology model is used? (tabulated)
  CHARACTER(len=6), SAVE, DIMENSION(npft)               :: pheno_model_tab
  ! type of senescence, tabulated
  CHARACTER(len=6), SAVE, DIMENSION(npft)               :: senescence_type_tab
  ! critical temperature for senescence (C), constant c of aT^2+bT+c , tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: senescence_temp1_tab
  ! critical temperature for senescence (C), constant b of aT^2+bT+c , tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: senescence_temp2_tab
  ! critical temperature for senescence (C), constant a of aT^2+bT+c , tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: senescence_temp3_tab
  ! critical relative moisture availability for senescence
  REAL(stnd), SAVE, DIMENSION(npft)                     :: senescence_hum_tab
  ! relative moisture availability above which there is no humidity-related senescence
  REAL(stnd), SAVE, DIMENSION(npft)                     :: nosenescence_hum_tab
 ! maximum turnover time for grasse
  REAL(stnd), SAVE, DIMENSION(npft)                     :: max_turnover_time_tab
 ! minimum turnover time for grasse
  REAL(stnd), SAVE, DIMENSION(npft)                     :: min_turnover_time_tab

  ! slope of maintenance respiration coefficient (1/K), constant c of aT^2+bT+c , tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: maint_resp_slope1_tab
  ! slope of maintenance respiration coefficient (1/K), constant b of aT^2+bT+c , tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: maint_resp_slope2_tab
  ! slope of maintenance respiration coefficient (1/K), constant a of aT^2+bT+c , tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: maint_resp_slope3_tab
  ! maintenance respiration coefficient (g/g/day) at 0 deg C, for leaves, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: cm_zero_leaf_tab
  ! maintenance respiration coefficient (g/g/day) at 0 deg C, for sapwood above, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: cm_zero_sapabove_tab
  ! maintenance respiration coefficient (g/g/day) at 0 deg C, for sapwood below, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: cm_zero_sapbelow_tab
  ! maintenance respiration coefficient (g/g/day) at 0 deg C, for heartwood above, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: cm_zero_heartabove_tab
  ! maintenance respiration coefficient (g/g/day) at 0 deg C, for heartwood below, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: cm_zero_heartbelow_tab
  ! maintenance respiration coefficient (g/g/day) at 0 deg C, for roots, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: cm_zero_root_tab
  ! maintenance respiration coefficient (g/g/day) at 0 deg C, for fruits, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: cm_zero_fruit_tab
  ! maintenance respiration coefficient (g/g/day) at 0 deg C, for carbohydrate reserve, tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: cm_zero_carbres_tab
  ! minimum photosynthesis temperature, constant a of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_min_a_tab
  ! minimum photosynthesis temperature, constant b of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_min_b_tab
  ! minimum photosynthesis temperature, constant c of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_min_c_tab
  ! optimum photosynthesis temperature, constant a of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_opt_a_tab
  ! optimum photosynthesis temperature, constant b of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_opt_b_tab
  ! optimum photosynthesis temperature, constant c of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_opt_c_tab
  ! maximum photosynthesis temperature, constant a of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_max_a_tab
  ! maximum photosynthesis temperature, constant b of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_max_b_tab
  ! maximum photosynthesis temperature, constant c of ax^2+bx+c (deg C), tabulated
  REAL(stnd), SAVE, DIMENSION(npft)                     :: tphoto_max_c_tab

  ! tables

  DATA PFT_name               / 'tropical  broad-leaved evergreen  ', &
                                'tropical  broad-leaved raingreen  ', &
                                'temperate needleleaf   evergreen  ', &
                                'temperate broad-leaved evergreen  ', &
                                'temperate broad-leaved summergreen', &
                                'boreal    needleleaf   evergreen  ', &
                                'boreal    broad-leaved summergreen', &
                                'boreal    needleleaf   summergreen', &
                                '          C3           grass      ', &
                                '          C4           grass      ', & 
                                '          C3           agriculture', &
                                '          C4           agriculture'   /

  ! 1=broad leaved tree, 2=needle leaved tree, 3=grass
  DATA leaf_tab               /       1,       1,       2,       1,       1,       2,   &
                                      1,       2,       3,       3,       3,       3 /

  DATA natural                /  .TRUE.,  .TRUE.,  .TRUE.,  .TRUE.,  .TRUE.,  .TRUE.,   &
                                 .TRUE.,  .TRUE.,  .TRUE.,  .TRUE., .FALSE., .FALSE. /

  DATA flam                   /     .25,     .25,     .25,     .25,     .25,     .25,   &
                                    .25,     .25,     .30,     .30,     .35,     .35 /
  ! DATA flam                   /     .15,     .15,     .15,     .15,     .15,     .15,   &
  !                                   .15,     .15,     .15,     .15,     .15,     .15 /

  DATA resist                 /     .12,     .50,     .12,     .50,     .12,     .12,   &
                                    .12,     .12,      .0,      .0,      .0,      .0 /

  DATA lai_max                /     7.,     7.,      5.,      5.,      5.,     4.5,   &
                                    4.5,     3.0,     2.5,     2.5,     5.,     5. /

  DATA residence_time         /    30.0,    30.0,    40.0,    40.0,    40.0,    80.0,   &
                                   80.0,    80.0,     0.0,     0.0,     0.0,     0.0 /

  DATA leaflife_tab           /      .5,      1.,      .5,      .5,      1.,      .5,   &
                                     1.,      1.,      1.,      1.,      1.,      1. /

  ! 1=evergreen,  2=summergreen,  3=raingreen,  4=perennial
  DATA pheno_type_tab         /       1,       3,       1,       1,       2,       1,   &
                                      2,       2,       4,       4,       2,       3 /

  DATA tmin_crit_tab          /     0.0,     0.0,   -45.0,   -10.0,   -45.0,   -60.0,   &
                                  -60.0,   undef,   undef,   undef,   undef,   undef /

  DATA tcm_crit_tab           /   undef,   undef,     5.0,    15.5,    15.5,    -2.0,   &
                                    5.0,    -2.0,   undef,   undef,   undef,   undef /

  DATA gdd_crit1_tab          /   undef,   undef,   undef,   undef,   undef,   undef,   &
                                  undef,   undef, 184.375,    400.,    125.,    400. /
  DATA gdd_crit2_tab          /   undef,   undef,   undef,   undef,   undef,   undef,   &
                                  undef,   undef,    6.25,      0.,      0.,       0. /
  DATA gdd_crit3_tab          /   undef,   undef,   undef,   undef,   undef,   undef,   &
                                  undef,   undef, 0.03125,      0.,      0.,       0. /

  DATA ngd_crit_tab           /   undef,   undef,   undef,   undef,   undef,   undef,   &
                                  undef,     17.,   undef,   undef,   undef,   undef /

  DATA ncdgdd_temp_tab        /   undef,   undef,   undef,   undef,      5.,   undef,   &
                                     0.,   undef,   undef,   undef,   undef,   undef /

  DATA hum_frac_tab           /   undef,      .5,   undef,   undef,   undef,   undef,   &
                                  undef,   undef,      .5,      .5,      .5,      .5 /

  DATA lowgpp_time_tab        /   undef,     30.,   undef,   undef,     30.,   undef,   &
                                    30.,     30.,     30.,     30.,     30.,     30. /

  DATA hum_min_time_tab       /   undef,     50.,   undef,   undef,   undef,   undef,   &
                                  undef,   undef,     35.,     35.,     75.,     75. /

  DATA tau_sap                /    730.,    730.,    730.,    730.,    730.,    730.,   &
                                   730.,    730.,   undef,   undef,   undef,   undef /

  DATA tau_fruit              /     90.,     90.,     90.,     90.,     90.,     90.,   &
                                    90.,     90.,   undef,   undef,   undef,   undef /

  DATA ecureuil               /      .0,      1.,      .0,      .0,      1.,      .0,   &
                                     1.,      1.,      1.,      1.,      1.,      1. /

  DATA vcmax_opt              /     65.,     65.,     35.,     40.,     55.,     35.,   &
                                    45.,     35.,     80.,     80.,    100.,    100. /

  DATA vjmax_opt              /    130.,    130.,     70.,     80.,    110.,     70.,   &
                                    90.,     70.,    160.,    160.,    200.,    200. /

  !DATA vcmax_opt_tab          /     65.,     65.,    37.5,     45.,     60.,    37.5,   &
  !                                  50.,     40.,    100.,    100.,    100.,    100. /
 
  !DATA vjmax_opt_tab          /    130.,    130.,     75.,     90.,    120.,     75.,   &
  !                                 100.,     80.,    200.,    200.,    200.,    200. /

  DATA leaffall_tab           /   undef,     10.,   undef,   undef,     10.,   undef,   &
                                    10.,     10.,     10.,     10.,     10.,     10. /

  DATA leafagecrit_tab        /    730.,    180.,    910.,    730.,    180.,    910.,   &
                                   180.,    180.,    120.,    120.,    120.,    120. /

  DATA ipft_sechiba           /       2,       3,       4,       5,       6,       7,   &
                                      8,       9,      10,      11,      12,      13 /

  DATA senescence_type_tab    /  'none',   'dry',  'none',  'none',  'cold',  'none',   &
                                 'cold',  'cold', 'mixed', 'mixed', 'mixed', 'mixed' /

  DATA senescence_temp1_tab   /   undef,   undef,   undef,   undef,     12.,   undef,   &
                                     7.,      2.,  -1.375,      5.,      5.,     10. /
  DATA senescence_temp2_tab   /   undef,   undef,   undef,   undef,      0.,   undef,   &
                                     0.,      0.,      .1,      0.,      0.,      0. /
  DATA senescence_temp3_tab   /   undef,   undef,   undef,   undef,      0.,   undef,   &
                                     0.,      0.,  .00375,      0.,      0.,      0. /

  DATA senescence_hum_tab     /   undef,      .6,   undef,   undef,   undef,   undef,   &
                                  undef,   undef,      .2,      .2,      .3,      .2 /

  DATA nosenescence_hum_tab   /   undef,      1.,   undef,   undef,   undef,   undef,   &
                                  undef,   undef,      .3,      .3,      .3,      .3 /

  DATA max_turnover_time_tab   /   undef,  undef,   undef,   undef,   undef,   undef,   &
                                  undef,   undef,      80.,  80.,    80.,    80. /

  DATA min_turnover_time_tab   /   undef,  undef,   undef,   undef,   undef,   undef,   &
                                  undef,   undef,      10.,      10.,      10.,      10. /


  DATA pheno_model_tab        /  'none',   'moi',  'none',  'none','ncdgdd',  'none',   &
                               'ncdgdd',   'ngd','moigdd','moigdd','moigdd','moigdd' /

  ! DATA maint_resp_slope1_tab  /     .16,     .16,     .16,     .16,     .16,     .16,   &
  !                                   .16,     .16,     .16,     .16,     .16,     .16 /
  ! DATA maint_resp_slope2_tab  /      .0,      .0,      .0,      .0,      .0,      .0,   &
  !                                    .0,      .0,      .0,      .0,      .0,      .0 /
  DATA maint_resp_slope1_tab  /     .12,     .12,     .16,     .16,     .16,     .16,   &
                                    .16,     .16,     .16,     .12,     .16,     .12 /
  DATA maint_resp_slope2_tab  /      .0,      .0,      .0,      .0,      .0,      .0,   &
                                     .0,      .0, -.00133,      .0, -.00133,      .0 /
  DATA maint_resp_slope3_tab  /      .0,      .0,      .0,      .0,      .0,      .0,   &
                                     .0,      .0,      .0,      .0,      .0,      .0 /

  DATA cm_zero_leaf_tab       / 2.35E-3, 2.62E-3, 1.01E-3, 2.35E-3, 2.62E-3, 1.01E-3,   &
                                2.62E-3, 2.05E-3, 2.62E-3, 2.62E-3, 2.62E-3, 2.62E-3 /

  DATA cm_zero_sapabove_tab   / 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,   &
                                1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4 /

  DATA cm_zero_sapbelow_tab   / 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,   &
                                1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4 /

  DATA cm_zero_heartabove_tab /      0.,      0.,      0.,      0.,      0.,      0.,   &
                                     0.,      0.,      0.,      0.,      0.,      0. /

  DATA cm_zero_heartbelow_tab /      0.,      0.,      0.,      0.,      0.,      0.,   &
                                     0.,      0.,      0.,      0.,      0.,      0. /

  DATA cm_zero_root_tab       / 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3,   &
                                1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3, 1.67E-3 /

  DATA cm_zero_fruit_tab      / 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,   &
                                1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4 /

  DATA cm_zero_carbres_tab    / 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4,   &
                                1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4, 1.19E-4 /

  DATA tphoto_min_c_tab       /      2.,      2.,     -4.,     -3.,     -2.,     -4.,   &
                                    -4.,     -4.,   -3.25,     13.,     -5.,     13. /
  DATA tphoto_min_b_tab       /      0.,      0.,      0.,      0.,      0.,      0.,   &
                                     0.,      0.,     0.1,      0.,      0.,      0. /
  DATA tphoto_min_a_tab       /      0.,      0.,      0.,      0.,      0.,      0.,   &
                                     0.,      0.,  0.0025,      0.,      0.,      0. /
  DATA tphoto_opt_c_tab       /     37.,     37.,     25.,     32.,     26.,     25.,   &
                                    25.,     25.,   27.25,     36.,     30.,     36. /
  DATA tphoto_opt_b_tab       /      0.,      0.,      0.,      0.,      0.,      0.,   &
                                     0.,      0.,    0.25,      0.,      0.,      0. /
  DATA tphoto_opt_a_tab       /      0.,      0.,      0.,      0.,      0.,      0.,   &
                                     0.,      0.,  0.0025,      0.,      0.,      0. /
  DATA tphoto_max_c_tab       /     55.,     55.,     38.,     48.,     38.,     38.,   &
                                    38.,     38.,  41.125,     55.,     45.,     55. /
  DATA tphoto_max_b_tab       /      0.,      0.,      0.,      0.,      0.,      0.,   &
                                     0.,      0.,    0.35,      0.,      0.,      0. /
  DATA tphoto_max_a_tab       /      0.,      0.,      0.,      0.,      0.,      0.,   &
                                     0.,      0., 0.00375,      0.,      0.,      0. /

END MODULE stomate_constants
